%Written by Carita Gyldenskog Ranvik, Trondheim 10.06.2019
% CALCULATING ENGINE BREAK POWER FROM RESISTANCE MODEL TEST, OPEN WATER MODEL
% TEST AND SELF-PROPULSION TEST

%Test values
% R_TS=900000; %[N] Total resistance
% V_s=15; %[knt] Ship speed
%ETA_M=1; %mechanical efficiency
%ETA_O propeller efficiency

%Input unit R_TS[N], V_s[knt], ETA_M[-]
%Output units P_B[W], n[1/s], ETA_0[-]
function [P_B, P_D, n, ETA_O]=Break_power(R_TS, V_s,ETA_M)

addpath('M:\carita\Prepocessing of data for simulation V5\Open water characteristics from model test')
load('OpenWaterChar_workspaceV2.mat','D_s','ETA','ETAR','J','KQ10','KT','rho','THDF','V_tw','WFT');
%Converting speed to SI unit
V_s_SI=V_s*(1852/(60*60)); %[m/s]


%Finding thrust deduction fraction and taylor wake fraction
if V_s<min(V_tw)
    t=THDF(1);
    w=WFT(1);
    ETA_R=ETAR(1);
elseif V_s>max(V_tw)
      t=THDF(length(THDF));
    w=WFT(length(WFT)); 
    ETA_R=ETAR(length(ETAR));
else 
    t=interp1(V_tw,THDF,V_s);
    w=interp1(V_tw,WFT,V_s);
    ETA_R=interp1(V_tw,ETAR,V_s);
end

%%Finding working point of propeller
KTS_vec=(R_TS*J.^2)/((1-t)*(1-w)^2*V_s_SI^2*D_s^2*rho); 

%Finding intersecting point of KT and KTS
Js=vec2D_intersect(KT,KTS_vec,J);

KQS=(interp1(J,KQ10,Js))/10;
ETA_O=interp1(J,ETA,Js);

%%Propeller rate of revolutions
n=V_s_SI*(1-w)/(Js*D_s); %[1/s]

%%Delivered power
P_D=2*pi*rho*n^3*D_s^5*KQS/ETA_R; %[W]

%%Engine break power
P_B=P_D/ETA_M; %[W]


%plot(J,KT,J,KQ10,J,ETA,J,KTS_vec)
end



