%Written by Carita Gyldenskog Ranvik, Trondheim 10.06.2019
%statistical wave data for the world wide trade

%Variables
% Tp=3.5:0.5:17.5; %[s]
% Tz=(3.5:0.5:17.5)*0.71; %[s]
% use when checking table
Tp=3:24; %[s]
Tz=Tp/0.71; %[s]

% load('T_p.mat');
% Tp=T_p;
% Tz=0.71*Tp;
Hs=1:14; % [m]

%constants from DNVGL-RP-C205 table C-5
alfa_Hs=1.798;
beta_Hs=1.214;
gamma_Hs=0.856; %not valid for Hs lower than 0.856
a0=-1.010;
a1=2.847;
a2=0.075;
b0=0.161;
b1=0.146;
b2=-0.683;

%Declearing variables
f_Hs=zeros(length(Hs),1);
f_Tz_Hs=zeros(length(Hs),length(Tz));
f_Tp_Hs=zeros(length(Hs),length(Tz));
stat_diagram_Tz=zeros(length(Hs),length(Tz));
stat_diagram_Tp=zeros(length(Hs),length(Tp));
HsTp_stat=zeros(length(Hs),length(Tp));
my=zeros(1,length(Hs));
sigma=zeros(1,length(Hs));
%Equations from section 3.6.3.4

%Significant wave height modelled by a 3-parameter weibull probability
%density function
for i=1:length(Hs)
f_Hs(i)=(beta_Hs/alfa_Hs)*(((Hs(i)-gamma_Hs)/alfa_Hs)^(beta_Hs-1))*exp(-((Hs(i)-gamma_Hs)/alfa_Hs)^beta_Hs);
my(i)=a0+a1*Hs(i)^a2;
sigma(i)=b0+b1*exp(b2*Hs(i));
%Zero-crossing wave period conditional on Hs is modelled by a lognormal
%distribution
for j=1:length(Tz)
    %Tz
    f_Tz_Hs(i,j)=(1/(sigma(i)*Tz(j)*sqrt(2*pi)))*exp(-(((log(Tz(j))-my(i))^2)/(2*sigma(i)^2)));
    stat_diagram_Tz(i,j)=f_Hs(i)*f_Tz_Hs(i,j);
    %Tp
    f_Tp_Hs(i,j)=(1/(sigma(i)*Tp(j)*sqrt(2*pi)))*exp(-(((log(Tp(j))-my(i))^2)/(2*sigma(i)^2)));
    stat_diagram_Tp(i,j)=f_Hs(i)*f_Tp_Hs(i,j);
    HsTp_stat(i,j)=f_Hs(i)*(f_Tp_Hs(i,j));
end
end
p_HsTp=HsTp_stat/(sum(sum(HsTp_stat)));
save('p_HsTp','p_HsTp');

%contour(stat_diagram_Tz)
% figure(1)
% plot(Hs,my)
% figure(2)
% plot(Hs,sigma)
